/* contacts-contact-sheet.c generated by valac 0.32.0.15-114e9, the Vala compiler
 * generated from contacts-contact-sheet.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 8 -*- */
/*
 * Copyright (C) 2011 Alexander Larsson <alexl@redhat.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <pango/pango.h>
#include <folks/folks.h>
#include <gee.h>
#include <gio/gio.h>
#include <telepathy-glib/telepathy-glib.h>
#include <folks/folks-telepathy.h>
#include <glib/gi18n-lib.h>


#define CONTACTS_TYPE_CONTACT_SHEET (contacts_contact_sheet_get_type ())
#define CONTACTS_CONTACT_SHEET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_CONTACT_SHEET, ContactsContactSheet))
#define CONTACTS_CONTACT_SHEET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_CONTACT_SHEET, ContactsContactSheetClass))
#define CONTACTS_IS_CONTACT_SHEET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_CONTACT_SHEET))
#define CONTACTS_IS_CONTACT_SHEET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_CONTACT_SHEET))
#define CONTACTS_CONTACT_SHEET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_CONTACT_SHEET, ContactsContactSheetClass))

typedef struct _ContactsContactSheet ContactsContactSheet;
typedef struct _ContactsContactSheetClass ContactsContactSheetClass;
typedef struct _ContactsContactSheetPrivate ContactsContactSheetPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define CONTACTS_TYPE_CONTACT (contacts_contact_get_type ())
#define CONTACTS_CONTACT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_CONTACT, ContactsContact))
#define CONTACTS_CONTACT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_CONTACT, ContactsContactClass))
#define CONTACTS_IS_CONTACT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_CONTACT))
#define CONTACTS_IS_CONTACT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_CONTACT))
#define CONTACTS_CONTACT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_CONTACT, ContactsContactClass))

typedef struct _ContactsContact ContactsContact;
typedef struct _ContactsContactClass ContactsContactClass;
typedef struct _Block16Data Block16Data;

#define CONTACTS_TYPE_CONTACT_FRAME (contacts_contact_frame_get_type ())
#define CONTACTS_CONTACT_FRAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_CONTACT_FRAME, ContactsContactFrame))
#define CONTACTS_CONTACT_FRAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_CONTACT_FRAME, ContactsContactFrameClass))
#define CONTACTS_IS_CONTACT_FRAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_CONTACT_FRAME))
#define CONTACTS_IS_CONTACT_FRAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_CONTACT_FRAME))
#define CONTACTS_CONTACT_FRAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_CONTACT_FRAME, ContactsContactFrameClass))

typedef struct _ContactsContactFrame ContactsContactFrame;
typedef struct _ContactsContactFrameClass ContactsContactFrameClass;
typedef struct _ContactsContactPrivate ContactsContactPrivate;

#define CONTACTS_TYPE_STORE (contacts_store_get_type ())
#define CONTACTS_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_STORE, ContactsStore))
#define CONTACTS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_STORE, ContactsStoreClass))
#define CONTACTS_IS_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_STORE))
#define CONTACTS_IS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_STORE))
#define CONTACTS_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_STORE, ContactsStoreClass))

typedef struct _ContactsStore ContactsStore;
typedef struct _ContactsStoreClass ContactsStoreClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block17Data Block17Data;

#define CONTACTS_TYPE_TYPESET (contacts_typeset_get_type ())
#define CONTACTS_TYPESET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_TYPESET, ContactsTypeSet))
#define CONTACTS_TYPESET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_TYPESET, ContactsTypeSetClass))
#define CONTACTS_IS_TYPESET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_TYPESET))
#define CONTACTS_IS_TYPESET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_TYPESET))
#define CONTACTS_TYPESET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_TYPESET, ContactsTypeSetClass))

typedef struct _ContactsTypeSet ContactsTypeSet;
typedef struct _ContactsTypeSetClass ContactsTypeSetClass;
typedef struct _Block18Data Block18Data;

#define CONTACTS_TYPE_APP (contacts_app_get_type ())
#define CONTACTS_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_APP, ContactsApp))
#define CONTACTS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_APP, ContactsAppClass))
#define CONTACTS_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_APP))
#define CONTACTS_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_APP))
#define CONTACTS_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_APP, ContactsAppClass))

typedef struct _ContactsApp ContactsApp;
typedef struct _ContactsAppClass ContactsAppClass;
typedef struct _ContactsAppPrivate ContactsAppPrivate;

#define CONTACTS_TYPE_WINDOW (contacts_window_get_type ())
#define CONTACTS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_WINDOW, ContactsWindow))
#define CONTACTS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_WINDOW, ContactsWindowClass))
#define CONTACTS_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_WINDOW))
#define CONTACTS_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_WINDOW))
#define CONTACTS_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_WINDOW, ContactsWindowClass))

typedef struct _ContactsWindow ContactsWindow;
typedef struct _ContactsWindowClass ContactsWindowClass;
typedef struct _ContactsStorePrivate ContactsStorePrivate;
typedef struct _Block19Data Block19Data;
typedef struct _Block20Data Block20Data;

#define CONTACTS_CONTACT_TYPE_IM_DISPLAY (contacts_contact_im_display_get_type ())
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

#define CONTACTS_TYPE_ADDRESS_MAP (contacts_address_map_get_type ())
#define CONTACTS_ADDRESS_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_ADDRESS_MAP, ContactsAddressMap))
#define CONTACTS_ADDRESS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_ADDRESS_MAP, ContactsAddressMapClass))
#define CONTACTS_IS_ADDRESS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_ADDRESS_MAP))
#define CONTACTS_IS_ADDRESS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_ADDRESS_MAP))
#define CONTACTS_ADDRESS_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_ADDRESS_MAP, ContactsAddressMapClass))

typedef struct _ContactsAddressMap ContactsAddressMap;
typedef struct _ContactsAddressMapClass ContactsAddressMapClass;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

struct _ContactsContactSheet {
	GtkGrid parent_instance;
	ContactsContactSheetPrivate * priv;
};

struct _ContactsContactSheetClass {
	GtkGridClass parent_class;
};

struct _Block16Data {
	int _ref_count_;
	ContactsContactSheet* self;
	ContactsContact* c;
};

struct _ContactsContact {
	GObject parent_instance;
	ContactsContactPrivate * priv;
	ContactsStore* store;
	gboolean is_main;
	FolksPresenceType presence_type;
	gchar* presence_message;
	gboolean is_phone;
	FolksIndividual* individual;
	FolksPersona* fake_persona;
};

struct _ContactsContactClass {
	GObjectClass parent_class;
};

struct _Block17Data {
	int _ref_count_;
	Block16Data * _data16_;
	FolksEmailFieldDetails* email;
};

struct _Block18Data {
	int _ref_count_;
	Block16Data * _data16_;
	FolksPhoneFieldDetails* phone;
};

struct _ContactsApp {
	GtkApplication parent_instance;
	ContactsAppPrivate * priv;
	GSettings* settings;
	ContactsStore* contacts_store;
	ContactsWindow* window;
};

struct _ContactsAppClass {
	GtkApplicationClass parent_class;
};

struct _ContactsStore {
	GObject parent_instance;
	ContactsStorePrivate * priv;
	GeeHashMap* calling_accounts;
	GeeHashMultiMap* dont_suggest_link;
};

struct _ContactsStoreClass {
	GObjectClass parent_class;
};

struct _Block19Data {
	int _ref_count_;
	Block16Data * _data16_;
	gchar* protocol;
};

struct _Block20Data {
	int _ref_count_;
	Block19Data * _data19_;
	FolksImFieldDetails* id;
};

typedef enum  {
	CONTACTS_CONTACT_IM_DISPLAY_DEFAULT,
	CONTACTS_CONTACT_IM_DISPLAY_ALIAS_SERVICE
} ContactsContactImDisplay;


static gpointer contacts_contact_sheet_parent_class = NULL;
extern ContactsApp* contacts_app_app;

GType contacts_contact_sheet_get_type (void) G_GNUC_CONST;
enum  {
	CONTACTS_CONTACT_SHEET_DUMMY_PROPERTY
};
static GtkButton* contacts_contact_sheet_add_row_with_button (ContactsContactSheet* self, gint* row, const gchar* label_value, const gchar* value);
static void contacts_contact_sheet_add_row_with_link_button (ContactsContactSheet* self, gint* row, const gchar* label_value, const gchar* value);
static void contacts_contact_sheet_add_row_with_label (ContactsContactSheet* self, gint* row, const gchar* label_value, const gchar* value);
ContactsContactSheet* contacts_contact_sheet_new (void);
ContactsContactSheet* contacts_contact_sheet_construct (GType object_type);
GType contacts_contact_get_type (void) G_GNUC_CONST;
void contacts_contact_sheet_update (ContactsContactSheet* self, ContactsContact* c);
static Block16Data* block16_data_ref (Block16Data* _data16_);
static void block16_data_unref (void * _userdata_);
GType contacts_contact_frame_get_type (void) G_GNUC_CONST;
#define PROFILE_SIZE 96
ContactsContactFrame* contacts_contact_frame_new (gint size, gboolean with_button);
ContactsContactFrame* contacts_contact_frame_construct (GType object_type, gint size, gboolean with_button);
void contacts_contact_keep_widget_uptodate (ContactsContact* self, GtkWidget* w, GtkCallback callback, void* callback_target, GDestroyNotify callback_target_destroy_notify);
static void __lambda29_ (Block16Data* _data16_, GtkWidget* w);
void contacts_contact_frame_set_image (ContactsContactFrame* self, FolksAvatarDetails* details, ContactsContact* contact);
GType contacts_store_get_type (void) G_GNUC_CONST;
static void ___lambda29__gtk_callback (GtkWidget* widget, gpointer self);
static void __lambda30_ (Block16Data* _data16_, GtkWidget* w);
const gchar* contacts_contact_get_display_name (ContactsContact* self);
static void ___lambda30__gtk_callback (GtkWidget* widget, gpointer self);
GeeList* contacts_contact_get_personas_for_display (ContactsContact* self);
gchar* contacts_contact_format_persona_store_name_for_contact (FolksPersona* persona);
GeeArrayList* contacts_contact_sort_fields (GType t_type, GBoxedCopyFunc t_dup_func, GDestroyNotify t_destroy_func, GeeCollection* fields);
static Block17Data* block17_data_ref (Block17Data* _data17_);
static void block17_data_unref (void * _userdata_);
GType contacts_typeset_get_type (void) G_GNUC_CONST;
ContactsTypeSet* contacts_typeset_get_email (void);
gchar* contacts_typeset_format_type (ContactsTypeSet* self, FolksAbstractFieldDetails* detail);
static void _______lambda31_ (Block17Data* _data17_);
void contacts_utils_compose_mail (const gchar* email);
static void ________lambda31__gtk_button_clicked (GtkButton* _sender, gpointer self);
static Block18Data* block18_data_ref (Block18Data* _data18_);
static void block18_data_unref (void * _userdata_);
GType contacts_app_get_type (void) G_GNUC_CONST;
GType contacts_window_get_type (void) G_GNUC_CONST;
gboolean contacts_store_get_can_call (ContactsStore* self);
ContactsTypeSet* contacts_typeset_get_phone (void);
static void ________lambda32_ (Block18Data* _data18_);
void contacts_utils_start_call (const gchar* contact_id, GeeHashMap* accounts);
static void _________lambda32__gtk_button_clicked (GtkButton* _sender, gpointer self);
static Block19Data* block19_data_ref (Block19Data* _data19_);
static void block19_data_unref (void * _userdata_);
static Block20Data* block20_data_ref (Block20Data* _data20_);
static void block20_data_unref (void * _userdata_);
GType contacts_contact_im_display_get_type (void) G_GNUC_CONST;
gchar* contacts_contact_format_im_service (const gchar* service, ContactsContactImDisplay* display);
static void __________lambda33_ (Block20Data* _data20_);
TpfPersona* contacts_contact_find_im_persona (ContactsContact* self, const gchar* protocol, const gchar* im_address);
void contacts_utils_start_chat (ContactsContact* contact, const gchar* protocol, const gchar* id);
static void ___________lambda33__gtk_button_clicked (GtkButton* _sender, gpointer self);
gboolean contacts_is_set (const gchar* str);
gchar** contacts_contact_format_address (FolksPostalAddress* addr, int* result_length1);
ContactsTypeSet* contacts_typeset_get_general (void);
GType contacts_address_map_get_type (void) G_GNUC_CONST;
ContactsAddressMap* contacts_address_map_new (ContactsContact* c, GeeSet* postal_addresses);
ContactsAddressMap* contacts_address_map_construct (GType object_type, ContactsContact* c, GeeSet* postal_addresses);
void contacts_address_map_load (ContactsAddressMap* self);
void contacts_contact_sheet_clear (ContactsContactSheet* self);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static GtkButton* contacts_contact_sheet_add_row_with_button (ContactsContactSheet* self, gint* row, const gchar* label_value, const gchar* value) {
	GtkButton* result = NULL;
	GtkLabel* type_label = NULL;
	const gchar* _tmp0_ = NULL;
	GtkLabel* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	GtkButton* value_button = NULL;
	const gchar* _tmp4_ = NULL;
	GtkButton* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	GtkWidget* _tmp8_ = NULL;
	GtkWidget* _tmp9_ = NULL;
#line 25 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 25 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_val_if_fail (label_value != NULL, NULL);
#line 25 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_val_if_fail (value != NULL, NULL);
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp0_ = label_value;
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp1_ = (GtkLabel*) gtk_label_new (_tmp0_);
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_object_ref_sink (_tmp1_);
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	type_label = _tmp1_;
#line 27 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_label_set_xalign (type_label, 1.0f);
#line 28 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_halign ((GtkWidget*) type_label, GTK_ALIGN_END);
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) type_label);
#line 29 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_style_context_add_class (_tmp2_, "dim-label");
#line 30 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp3_ = *row;
#line 30 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) type_label, 0, _tmp3_, 1, 1);
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp4_ = value;
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp5_ = (GtkButton*) gtk_button_new_with_label (_tmp4_);
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_object_ref_sink (_tmp5_);
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	value_button = _tmp5_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_focus_on_click ((GtkWidget*) value_button, FALSE);
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_button_set_relief (value_button, GTK_RELIEF_NONE);
#line 35 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_object_set (value_button, "xalign", 0.0f, NULL);
#line 36 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_hexpand ((GtkWidget*) value_button, TRUE);
#line 37 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp6_ = *row;
#line 37 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) value_button, 1, _tmp6_, 1, 1);
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp7_ = *row;
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	*row = _tmp7_ + 1;
#line 40 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp8_ = gtk_bin_get_child ((GtkBin*) value_button);
#line 40 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_label_set_ellipsize (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp8_) : NULL, PANGO_ELLIPSIZE_END);
#line 41 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp9_ = gtk_bin_get_child ((GtkBin*) value_button);
#line 41 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_object_set (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp9_) : NULL, "wrap-mode", PANGO_WRAP_CHAR, NULL);
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	result = value_button;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_g_object_unref0 (type_label);
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	return result;
#line 364 "contacts-contact-sheet.c"
}


static void contacts_contact_sheet_add_row_with_link_button (ContactsContactSheet* self, gint* row, const gchar* label_value, const gchar* value) {
	GtkLabel* type_label = NULL;
	const gchar* _tmp0_ = NULL;
	GtkLabel* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	GtkLinkButton* value_button = NULL;
	const gchar* _tmp4_ = NULL;
	GtkLinkButton* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	GtkWidget* _tmp8_ = NULL;
	GtkWidget* _tmp9_ = NULL;
#line 46 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_if_fail (self != NULL);
#line 46 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_if_fail (label_value != NULL);
#line 46 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_if_fail (value != NULL);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp0_ = label_value;
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp1_ = (GtkLabel*) gtk_label_new (_tmp0_);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_object_ref_sink (_tmp1_);
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	type_label = _tmp1_;
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_label_set_xalign (type_label, 1.0f);
#line 49 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_halign ((GtkWidget*) type_label, GTK_ALIGN_END);
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) type_label);
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_style_context_add_class (_tmp2_, "dim-label");
#line 51 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp3_ = *row;
#line 51 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) type_label, 0, _tmp3_, 1, 1);
#line 53 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp4_ = value;
#line 53 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp5_ = (GtkLinkButton*) gtk_link_button_new (_tmp4_);
#line 53 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_object_ref_sink (_tmp5_);
#line 53 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	value_button = _tmp5_;
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_focus_on_click ((GtkWidget*) value_button, FALSE);
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_button_set_relief ((GtkButton*) value_button, GTK_RELIEF_NONE);
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_object_set ((GtkButton*) value_button, "xalign", 0.0f, NULL);
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_hexpand ((GtkWidget*) value_button, TRUE);
#line 58 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp6_ = *row;
#line 58 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) value_button, 1, _tmp6_, 1, 1);
#line 59 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp7_ = *row;
#line 59 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	*row = _tmp7_ + 1;
#line 61 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp8_ = gtk_bin_get_child ((GtkBin*) value_button);
#line 61 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_label_set_ellipsize (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp8_) : NULL, PANGO_ELLIPSIZE_END);
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp9_ = gtk_bin_get_child ((GtkBin*) value_button);
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_object_set (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp9_) : NULL, "wrap-mode", PANGO_WRAP_CHAR, NULL);
#line 46 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_g_object_unref0 (value_button);
#line 46 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_g_object_unref0 (type_label);
#line 443 "contacts-contact-sheet.c"
}


static void contacts_contact_sheet_add_row_with_label (ContactsContactSheet* self, gint* row, const gchar* label_value, const gchar* value) {
	GtkLabel* type_label = NULL;
	const gchar* _tmp0_ = NULL;
	GtkLabel* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	GtkLabel* value_label = NULL;
	const gchar* _tmp4_ = NULL;
	GtkLabel* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
#line 65 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_if_fail (self != NULL);
#line 65 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_if_fail (label_value != NULL);
#line 65 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_if_fail (value != NULL);
#line 66 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp0_ = label_value;
#line 66 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp1_ = (GtkLabel*) gtk_label_new (_tmp0_);
#line 66 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_object_ref_sink (_tmp1_);
#line 66 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	type_label = _tmp1_;
#line 67 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_label_set_xalign (type_label, 1.0f);
#line 68 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_halign ((GtkWidget*) type_label, GTK_ALIGN_END);
#line 69 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_valign ((GtkWidget*) type_label, GTK_ALIGN_START);
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) type_label);
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_style_context_add_class (_tmp2_, "dim-label");
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp3_ = *row;
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) type_label, 0, _tmp3_, 1, 1);
#line 73 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp4_ = value;
#line 73 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp5_ = (GtkLabel*) gtk_label_new (_tmp4_);
#line 73 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_object_ref_sink (_tmp5_);
#line 73 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	value_label = _tmp5_;
#line 74 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_label_set_line_wrap (value_label, TRUE);
#line 75 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_label_set_xalign (value_label, 0.0f);
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_halign ((GtkWidget*) value_label, GTK_ALIGN_START);
#line 77 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_label_set_ellipsize (value_label, PANGO_ELLIPSIZE_END);
#line 78 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_object_set (value_label, "wrap-mode", PANGO_WRAP_CHAR, NULL);
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_margin_top ((GtkWidget*) type_label, 3);
#line 82 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_margin_start ((GtkWidget*) value_label, 6);
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_margin_top ((GtkWidget*) value_label, 3);
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) value_label, 3);
#line 86 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp6_ = *row;
#line 86 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) value_label, 1, _tmp6_, 1, 1);
#line 87 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp7_ = *row;
#line 87 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	*row = _tmp7_ + 1;
#line 65 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_g_object_unref0 (value_label);
#line 65 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_g_object_unref0 (type_label);
#line 524 "contacts-contact-sheet.c"
}


ContactsContactSheet* contacts_contact_sheet_construct (GType object_type) {
	ContactsContactSheet * self = NULL;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	self = (ContactsContactSheet*) g_object_new (object_type, NULL);
#line 91 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_grid_set_row_spacing ((GtkGrid*) self, (guint) 12);
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_grid_set_column_spacing ((GtkGrid*) self, (guint) 16);
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) self, GTK_ORIENTATION_VERTICAL);
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	return self;
#line 540 "contacts-contact-sheet.c"
}


ContactsContactSheet* contacts_contact_sheet_new (void) {
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	return contacts_contact_sheet_construct (CONTACTS_TYPE_CONTACT_SHEET);
#line 547 "contacts-contact-sheet.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	return self ? g_object_ref (self) : NULL;
#line 554 "contacts-contact-sheet.c"
}


static Block16Data* block16_data_ref (Block16Data* _data16_) {
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_atomic_int_inc (&_data16_->_ref_count_);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	return _data16_;
#line 563 "contacts-contact-sheet.c"
}


static void block16_data_unref (void * _userdata_) {
	Block16Data* _data16_;
	_data16_ = (Block16Data*) _userdata_;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	if (g_atomic_int_dec_and_test (&_data16_->_ref_count_)) {
#line 572 "contacts-contact-sheet.c"
		ContactsContactSheet* self;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		self = _data16_->self;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_g_object_unref0 (_data16_->c);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_g_object_unref0 (self);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		g_slice_free (Block16Data, _data16_);
#line 582 "contacts-contact-sheet.c"
	}
}


static void __lambda29_ (Block16Data* _data16_, GtkWidget* w) {
	ContactsContactSheet* self;
	GtkWidget* _tmp0_ = NULL;
	ContactsContact* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	ContactsContact* _tmp3_ = NULL;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	self = _data16_->self;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_if_fail (w != NULL);
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp0_ = w;
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp1_ = _data16_->c;
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp2_ = _tmp1_->individual;
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp3_ = _data16_->c;
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	contacts_contact_frame_set_image (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, CONTACTS_TYPE_CONTACT_FRAME) ? ((ContactsContactFrame*) _tmp0_) : NULL, (FolksAvatarDetails*) _tmp2_, _tmp3_);
#line 607 "contacts-contact-sheet.c"
}


static void ___lambda29__gtk_callback (GtkWidget* widget, gpointer self) {
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	__lambda29_ (self, widget);
#line 614 "contacts-contact-sheet.c"
}


static void __lambda30_ (Block16Data* _data16_, GtkWidget* w) {
	ContactsContactSheet* self;
	GtkWidget* _tmp0_ = NULL;
	ContactsContact* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	self = _data16_->self;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_if_fail (w != NULL);
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp0_ = w;
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp1_ = _data16_->c;
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp2_ = contacts_contact_get_display_name (_tmp1_);
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp3_ = _tmp2_;
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp4_ = g_markup_printf_escaped ("<span font='16'>%s</span>", _tmp3_);
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp5_ = _tmp4_;
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_label_set_markup (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp0_) : NULL, _tmp5_);
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_g_free0 (_tmp5_);
#line 646 "contacts-contact-sheet.c"
}


static void ___lambda30__gtk_callback (GtkWidget* widget, gpointer self) {
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	__lambda30_ (self, widget);
#line 653 "contacts-contact-sheet.c"
}


static Block17Data* block17_data_ref (Block17Data* _data17_) {
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_atomic_int_inc (&_data17_->_ref_count_);
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	return _data17_;
#line 662 "contacts-contact-sheet.c"
}


static void block17_data_unref (void * _userdata_) {
	Block17Data* _data17_;
	_data17_ = (Block17Data*) _userdata_;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	if (g_atomic_int_dec_and_test (&_data17_->_ref_count_)) {
#line 671 "contacts-contact-sheet.c"
		ContactsContactSheet* self;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		self = _data17_->_data16_->self;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_g_object_unref0 (_data17_->email);
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		block16_data_unref (_data17_->_data16_);
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_data17_->_data16_ = NULL;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		g_slice_free (Block17Data, _data17_);
#line 683 "contacts-contact-sheet.c"
	}
}


static void _______lambda31_ (Block17Data* _data17_) {
	Block16Data* _data16_;
	ContactsContactSheet* self;
	ContactsContact* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	FolksEmailFieldDetails* _tmp3_ = NULL;
	gconstpointer _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_data16_ = _data17_->_data16_;
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	self = _data16_->self;
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp0_ = _data16_->c;
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp1_ = contacts_contact_get_display_name (_tmp0_);
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp2_ = _tmp1_;
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp3_ = _data17_->email;
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp4_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp3_);
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp5_ = _tmp4_;
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp6_ = g_strdup_printf ("%s <%s>", _tmp2_, (const gchar*) _tmp5_);
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp7_ = _tmp6_;
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	contacts_utils_compose_mail (_tmp7_);
#line 144 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_g_free0 (_tmp7_);
#line 723 "contacts-contact-sheet.c"
}


static void ________lambda31__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_______lambda31_ (self);
#line 730 "contacts-contact-sheet.c"
}


static Block18Data* block18_data_ref (Block18Data* _data18_) {
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_atomic_int_inc (&_data18_->_ref_count_);
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	return _data18_;
#line 739 "contacts-contact-sheet.c"
}


static void block18_data_unref (void * _userdata_) {
	Block18Data* _data18_;
	_data18_ = (Block18Data*) _userdata_;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	if (g_atomic_int_dec_and_test (&_data18_->_ref_count_)) {
#line 748 "contacts-contact-sheet.c"
		ContactsContactSheet* self;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		self = _data18_->_data16_->self;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_g_object_unref0 (_data18_->phone);
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		block16_data_unref (_data18_->_data16_);
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_data18_->_data16_ = NULL;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		g_slice_free (Block18Data, _data18_);
#line 760 "contacts-contact-sheet.c"
	}
}


static void ________lambda32_ (Block18Data* _data18_) {
	Block16Data* _data16_;
	ContactsContactSheet* self;
	FolksPhoneFieldDetails* _tmp0_ = NULL;
	gconstpointer _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	ContactsApp* _tmp3_ = NULL;
	ContactsStore* _tmp4_ = NULL;
	GeeHashMap* _tmp5_ = NULL;
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_data16_ = _data18_->_data16_;
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	self = _data16_->self;
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp0_ = _data18_->phone;
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp1_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp0_);
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp2_ = _tmp1_;
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp3_ = contacts_app_app;
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp4_ = _tmp3_->contacts_store;
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp5_ = _tmp4_->calling_accounts;
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	contacts_utils_start_call ((const gchar*) _tmp2_, _tmp5_);
#line 792 "contacts-contact-sheet.c"
}


static void _________lambda32__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	________lambda32_ (self);
#line 799 "contacts-contact-sheet.c"
}


static Block19Data* block19_data_ref (Block19Data* _data19_) {
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_atomic_int_inc (&_data19_->_ref_count_);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	return _data19_;
#line 808 "contacts-contact-sheet.c"
}


static void block19_data_unref (void * _userdata_) {
	Block19Data* _data19_;
	_data19_ = (Block19Data*) _userdata_;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	if (g_atomic_int_dec_and_test (&_data19_->_ref_count_)) {
#line 817 "contacts-contact-sheet.c"
		ContactsContactSheet* self;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		self = _data19_->_data16_->self;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_g_free0 (_data19_->protocol);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		block16_data_unref (_data19_->_data16_);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_data19_->_data16_ = NULL;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		g_slice_free (Block19Data, _data19_);
#line 829 "contacts-contact-sheet.c"
	}
}


static Block20Data* block20_data_ref (Block20Data* _data20_) {
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_atomic_int_inc (&_data20_->_ref_count_);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	return _data20_;
#line 839 "contacts-contact-sheet.c"
}


static void block20_data_unref (void * _userdata_) {
	Block20Data* _data20_;
	_data20_ = (Block20Data*) _userdata_;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	if (g_atomic_int_dec_and_test (&_data20_->_ref_count_)) {
#line 848 "contacts-contact-sheet.c"
		ContactsContactSheet* self;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		self = _data20_->_data19_->_data16_->self;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_g_object_unref0 (_data20_->id);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		block19_data_unref (_data20_->_data19_);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_data20_->_data19_ = NULL;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		g_slice_free (Block20Data, _data20_);
#line 860 "contacts-contact-sheet.c"
	}
}


static void __________lambda33_ (Block20Data* _data20_) {
	Block19Data* _data19_;
	Block16Data* _data16_;
	ContactsContactSheet* self;
	TpfPersona* im_persona = NULL;
	ContactsContact* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	FolksImFieldDetails* _tmp2_ = NULL;
	gconstpointer _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	TpfPersona* _tmp5_ = NULL;
	TpfPersona* _tmp6_ = NULL;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_data19_ = _data20_->_data19_;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_data16_ = _data19_->_data16_;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	self = _data16_->self;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp0_ = _data16_->c;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp1_ = _data19_->protocol;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp2_ = _data20_->id;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp3_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp2_);
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp4_ = _tmp3_;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp5_ = contacts_contact_find_im_persona (_tmp0_, _tmp1_, (const gchar*) _tmp4_);
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	im_persona = _tmp5_;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp6_ = im_persona;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	if (_tmp6_ != NULL) {
#line 901 "contacts-contact-sheet.c"
		FolksPresenceType type = 0;
		TpfPersona* _tmp7_ = NULL;
		FolksPresenceType _tmp8_ = 0;
		FolksPresenceType _tmp9_ = 0;
		gboolean _tmp10_ = FALSE;
		gboolean _tmp11_ = FALSE;
		gboolean _tmp12_ = FALSE;
		FolksPresenceType _tmp13_ = 0;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_tmp7_ = im_persona;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_tmp8_ = folks_presence_details_get_presence_type ((FolksPresenceDetails*) _tmp7_);
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_tmp9_ = _tmp8_;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		type = _tmp9_;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_tmp13_ = type;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		if (_tmp13_ != FOLKS_PRESENCE_TYPE_UNSET) {
#line 922 "contacts-contact-sheet.c"
			FolksPresenceType _tmp14_ = 0;
#line 175 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp14_ = type;
#line 175 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp12_ = _tmp14_ != FOLKS_PRESENCE_TYPE_ERROR;
#line 928 "contacts-contact-sheet.c"
		} else {
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp12_ = FALSE;
#line 932 "contacts-contact-sheet.c"
		}
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		if (_tmp12_) {
#line 936 "contacts-contact-sheet.c"
			FolksPresenceType _tmp15_ = 0;
#line 176 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp15_ = type;
#line 176 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp11_ = _tmp15_ != FOLKS_PRESENCE_TYPE_OFFLINE;
#line 942 "contacts-contact-sheet.c"
		} else {
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp11_ = FALSE;
#line 946 "contacts-contact-sheet.c"
		}
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		if (_tmp11_) {
#line 950 "contacts-contact-sheet.c"
			FolksPresenceType _tmp16_ = 0;
#line 177 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp16_ = type;
#line 177 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp10_ = _tmp16_ != FOLKS_PRESENCE_TYPE_UNKNOWN;
#line 956 "contacts-contact-sheet.c"
		} else {
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp10_ = FALSE;
#line 960 "contacts-contact-sheet.c"
		}
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		if (_tmp10_) {
#line 964 "contacts-contact-sheet.c"
			ContactsContact* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			FolksImFieldDetails* _tmp19_ = NULL;
			gconstpointer _tmp20_ = NULL;
			const gchar* _tmp21_ = NULL;
#line 178 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp17_ = _data16_->c;
#line 178 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp18_ = _data19_->protocol;
#line 178 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp19_ = _data20_->id;
#line 178 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp20_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp19_);
#line 178 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp21_ = _tmp20_;
#line 178 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			contacts_utils_start_chat (_tmp17_, _tmp18_, (const gchar*) _tmp21_);
#line 982 "contacts-contact-sheet.c"
		}
	}
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_g_object_unref0 (im_persona);
#line 987 "contacts-contact-sheet.c"
}


static void ___________lambda33__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	__________lambda33_ (self);
#line 994 "contacts-contact-sheet.c"
}


void contacts_contact_sheet_update (ContactsContactSheet* self, ContactsContact* c) {
	Block16Data* _data16_;
	ContactsContact* _tmp0_ = NULL;
	ContactsContact* _tmp1_ = NULL;
	ContactsContactFrame* image_frame = NULL;
	ContactsContactFrame* _tmp2_ = NULL;
	ContactsContactFrame* _tmp3_ = NULL;
	GtkStyleContext* _tmp4_ = NULL;
	ContactsContactFrame* _tmp5_ = NULL;
	ContactsContactFrame* _tmp6_ = NULL;
	ContactsContactFrame* _tmp7_ = NULL;
	ContactsContact* _tmp8_ = NULL;
	ContactsContactFrame* _tmp9_ = NULL;
	ContactsContactFrame* _tmp10_ = NULL;
	GtkLabel* name_label = NULL;
	GtkLabel* _tmp11_ = NULL;
	GtkLabel* _tmp12_ = NULL;
	GtkLabel* _tmp13_ = NULL;
	GtkLabel* _tmp14_ = NULL;
	GtkLabel* _tmp15_ = NULL;
	GtkLabel* _tmp16_ = NULL;
	GtkLabel* _tmp17_ = NULL;
	ContactsContact* _tmp18_ = NULL;
	GtkLabel* _tmp19_ = NULL;
	GtkLabel* _tmp20_ = NULL;
	gint i = 0;
	gint last_store_position = 0;
	gboolean is_first_persona = FALSE;
	GeeList* personas = NULL;
	ContactsContact* _tmp21_ = NULL;
	GeeList* _tmp22_ = NULL;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_if_fail (self != NULL);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_if_fail (c != NULL);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_data16_ = g_slice_new0 (Block16Data);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_data16_->_ref_count_ = 1;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_data16_->self = g_object_ref (self);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp0_ = c;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_g_object_unref0 (_data16_->c);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_data16_->c = _tmp1_;
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp2_ = contacts_contact_frame_new (PROFILE_SIZE, FALSE);
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_object_ref_sink (_tmp2_);
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	image_frame = _tmp2_;
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp3_ = image_frame;
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) _tmp3_);
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_style_context_add_class (_tmp4_, "main-avatar-frame");
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp5_ = image_frame;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_frame_set_shadow_type ((GtkFrame*) _tmp5_, GTK_SHADOW_IN);
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp6_ = image_frame;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_vexpand ((GtkWidget*) _tmp6_, FALSE);
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp7_ = image_frame;
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp7_, GTK_ALIGN_START);
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp8_ = _data16_->c;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp9_ = image_frame;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	contacts_contact_keep_widget_uptodate (_tmp8_, (GtkWidget*) _tmp9_, ___lambda29__gtk_callback, block16_data_ref (_data16_), block16_data_unref);
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp10_ = image_frame;
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp10_, 0, 0, 1, 3);
#line 107 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp11_ = (GtkLabel*) gtk_label_new (NULL);
#line 107 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_object_ref_sink (_tmp11_);
#line 107 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	name_label = _tmp11_;
#line 108 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp12_ = name_label;
#line 108 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp12_, TRUE);
#line 109 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp13_ = name_label;
#line 109 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp13_, GTK_ALIGN_START);
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp14_ = name_label;
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp14_, GTK_ALIGN_CENTER);
#line 111 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp15_ = name_label;
#line 111 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_set_margin_start ((GtkWidget*) _tmp15_, 6);
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp16_ = name_label;
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_label_set_ellipsize (_tmp16_, PANGO_ELLIPSIZE_END);
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp17_ = name_label;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_label_set_xalign (_tmp17_, 0.0f);
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp18_ = _data16_->c;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp19_ = name_label;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	contacts_contact_keep_widget_uptodate (_tmp18_, (GtkWidget*) _tmp19_, ___lambda30__gtk_callback, block16_data_ref (_data16_), block16_data_unref);
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp20_ = name_label;
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp20_, 1, 0, 1, 3);
#line 120 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	i = 3;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	last_store_position = 0;
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	is_first_persona = TRUE;
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp21_ = _data16_->c;
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp22_ = contacts_contact_get_personas_for_display (_tmp21_);
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	personas = _tmp22_;
#line 1133 "contacts-contact-sheet.c"
	{
		GeeList* _p_list = NULL;
		GeeList* _tmp23_ = NULL;
		GeeList* _tmp24_ = NULL;
		gint _p_size = 0;
		GeeList* _tmp25_ = NULL;
		gint _tmp26_ = 0;
		gint _tmp27_ = 0;
		gint _p_index = 0;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_tmp23_ = personas;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_tmp24_ = _g_object_ref0 (_tmp23_);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_p_list = _tmp24_;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_tmp25_ = _p_list;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_tmp26_ = gee_collection_get_size ((GeeCollection*) _tmp25_);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_tmp27_ = _tmp26_;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_p_size = _tmp27_;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_p_index = -1;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		while (TRUE) {
#line 1161 "contacts-contact-sheet.c"
			gint _tmp28_ = 0;
			gint _tmp29_ = 0;
			gint _tmp30_ = 0;
			FolksPersona* p = NULL;
			GeeList* _tmp31_ = NULL;
			gint _tmp32_ = 0;
			gpointer _tmp33_ = NULL;
			gboolean _tmp34_ = FALSE;
			FolksEmailDetails* details = NULL;
			FolksPersona* _tmp49_ = NULL;
			FolksEmailDetails* _tmp50_ = NULL;
			FolksEmailDetails* _tmp51_ = NULL;
			FolksPhoneDetails* phone_details = NULL;
			FolksPersona* _tmp78_ = NULL;
			FolksPhoneDetails* _tmp79_ = NULL;
			FolksPhoneDetails* _tmp80_ = NULL;
			FolksImDetails* im_details = NULL;
			FolksPersona* _tmp119_ = NULL;
			FolksImDetails* _tmp120_ = NULL;
			FolksImDetails* _tmp121_ = NULL;
			FolksUrlDetails* url_details = NULL;
			FolksPersona* _tmp155_ = NULL;
			FolksUrlDetails* _tmp156_ = NULL;
			FolksUrlDetails* _tmp157_ = NULL;
			FolksNameDetails* name_details = NULL;
			FolksPersona* _tmp170_ = NULL;
			FolksNameDetails* _tmp171_ = NULL;
			FolksNameDetails* _tmp172_ = NULL;
			FolksBirthdayDetails* birthday_details = NULL;
			FolksPersona* _tmp181_ = NULL;
			FolksBirthdayDetails* _tmp182_ = NULL;
			FolksBirthdayDetails* _tmp183_ = NULL;
			FolksNoteDetails* note_details = NULL;
			FolksPersona* _tmp195_ = NULL;
			FolksNoteDetails* _tmp196_ = NULL;
			FolksNoteDetails* _tmp197_ = NULL;
			FolksPostalAddressDetails* addr_details = NULL;
			FolksPersona* _tmp210_ = NULL;
			FolksPostalAddressDetails* _tmp211_ = NULL;
			FolksPostalAddressDetails* _tmp212_ = NULL;
			gint _tmp254_ = 0;
			gint _tmp255_ = 0;
			gint _tmp256_ = 0;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp28_ = _p_index;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_p_index = _tmp28_ + 1;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp29_ = _p_index;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp30_ = _p_size;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			if (!(_tmp29_ < _tmp30_)) {
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				break;
#line 1217 "contacts-contact-sheet.c"
			}
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp31_ = _p_list;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp32_ = _p_index;
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp33_ = gee_list_get (_tmp31_, _tmp32_);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			p = (FolksPersona*) _tmp33_;
#line 127 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp34_ = is_first_persona;
#line 127 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			if (!_tmp34_) {
#line 1231 "contacts-contact-sheet.c"
				GtkLabel* store_name = NULL;
				GtkLabel* _tmp35_ = NULL;
				GtkLabel* _tmp36_ = NULL;
				FolksPersona* _tmp37_ = NULL;
				gchar* _tmp38_ = NULL;
				gchar* _tmp39_ = NULL;
				gchar* _tmp40_ = NULL;
				gchar* _tmp41_ = NULL;
				GtkLabel* _tmp42_ = NULL;
				GtkLabel* _tmp43_ = NULL;
				GtkLabel* _tmp44_ = NULL;
				GtkLabel* _tmp45_ = NULL;
				gint _tmp46_ = 0;
				gint _tmp47_ = 0;
				gint _tmp48_ = 0;
#line 128 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp35_ = (GtkLabel*) gtk_label_new ("");
#line 128 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				g_object_ref_sink (_tmp35_);
#line 128 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				store_name = _tmp35_;
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp36_ = store_name;
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp37_ = p;
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp38_ = contacts_contact_format_persona_store_name_for_contact (_tmp37_);
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp39_ = _tmp38_;
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp40_ = g_markup_printf_escaped ("<span font='16px bold'>%s</span>", _tmp39_);
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp41_ = _tmp40_;
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				gtk_label_set_markup (_tmp36_, _tmp41_);
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_g_free0 (_tmp41_);
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_g_free0 (_tmp39_);
#line 131 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp42_ = store_name;
#line 131 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				gtk_widget_set_halign ((GtkWidget*) _tmp42_, GTK_ALIGN_START);
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp43_ = store_name;
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				gtk_label_set_xalign (_tmp43_, 0.0f);
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp44_ = store_name;
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				gtk_widget_set_margin_start ((GtkWidget*) _tmp44_, 6);
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp45_ = store_name;
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp46_ = i;
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp45_, 0, _tmp46_, 3, 1);
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp47_ = i;
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				i = _tmp47_ + 1;
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp48_ = i;
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				last_store_position = _tmp48_;
#line 127 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_g_object_unref0 (store_name);
#line 1299 "contacts-contact-sheet.c"
			}
#line 138 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp49_ = p;
#line 138 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp50_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp49_, FOLKS_TYPE_EMAIL_DETAILS) ? ((FolksEmailDetails*) _tmp49_) : NULL);
#line 138 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			details = _tmp50_;
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp51_ = details;
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			if (_tmp51_ != NULL) {
#line 1311 "contacts-contact-sheet.c"
				GeeArrayList* emails = NULL;
				FolksEmailDetails* _tmp52_ = NULL;
				GeeSet* _tmp53_ = NULL;
				GeeSet* _tmp54_ = NULL;
				GeeArrayList* _tmp55_ = NULL;
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp52_ = details;
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp53_ = folks_email_details_get_email_addresses (_tmp52_);
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp54_ = _tmp53_;
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp55_ = contacts_contact_sort_fields (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, (GeeCollection*) _tmp54_);
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				emails = _tmp55_;
#line 1327 "contacts-contact-sheet.c"
				{
					GeeArrayList* _email_list = NULL;
					GeeArrayList* _tmp56_ = NULL;
					GeeArrayList* _tmp57_ = NULL;
					gint _email_size = 0;
					GeeArrayList* _tmp58_ = NULL;
					gint _tmp59_ = 0;
					gint _tmp60_ = 0;
					gint _email_index = 0;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp56_ = emails;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp57_ = _g_object_ref0 (_tmp56_);
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_email_list = _tmp57_;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp58_ = _email_list;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp59_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp58_);
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp60_ = _tmp59_;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_email_size = _tmp60_;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_email_index = -1;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					while (TRUE) {
#line 1355 "contacts-contact-sheet.c"
						Block17Data* _data17_;
						gint _tmp61_ = 0;
						gint _tmp62_ = 0;
						gint _tmp63_ = 0;
						GeeArrayList* _tmp64_ = NULL;
						gint _tmp65_ = 0;
						gpointer _tmp66_ = NULL;
						GtkButton* button = NULL;
						ContactsTypeSet* _tmp67_ = NULL;
						ContactsTypeSet* _tmp68_ = NULL;
						FolksEmailFieldDetails* _tmp69_ = NULL;
						gchar* _tmp70_ = NULL;
						gchar* _tmp71_ = NULL;
						FolksEmailFieldDetails* _tmp72_ = NULL;
						gconstpointer _tmp73_ = NULL;
						const gchar* _tmp74_ = NULL;
						GtkButton* _tmp75_ = NULL;
						GtkButton* _tmp76_ = NULL;
						GtkButton* _tmp77_ = NULL;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data17_ = g_slice_new0 (Block17Data);
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data17_->_ref_count_ = 1;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data17_->_data16_ = block16_data_ref (_data16_);
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp61_ = _email_index;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_email_index = _tmp61_ + 1;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp62_ = _email_index;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp63_ = _email_size;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						if (!(_tmp62_ < _tmp63_)) {
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							block17_data_unref (_data17_);
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_data17_ = NULL;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							break;
#line 1397 "contacts-contact-sheet.c"
						}
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp64_ = _email_list;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp65_ = _email_index;
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp66_ = gee_abstract_list_get ((GeeAbstractList*) _tmp64_, _tmp65_);
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data17_->email = (FolksEmailFieldDetails*) _tmp66_;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp67_ = contacts_typeset_get_email ();
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp68_ = _tmp67_;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp69_ = _data17_->email;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp70_ = contacts_typeset_format_type (_tmp68_, (FolksAbstractFieldDetails*) _tmp69_);
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp71_ = _tmp70_;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp72_ = _data17_->email;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp73_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp72_);
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp74_ = _tmp73_;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp75_ = contacts_contact_sheet_add_row_with_button (self, &i, _tmp71_, (const gchar*) _tmp74_);
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp76_ = _tmp75_;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_g_free0 (_tmp71_);
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						button = _tmp76_;
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp77_ = button;
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						g_signal_connect_data (_tmp77_, "clicked", (GCallback) ________lambda31__gtk_button_clicked, block17_data_ref (_data17_), (GClosureNotify) block17_data_unref, 0);
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_g_object_unref0 (button);
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						block17_data_unref (_data17_);
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data17_ = NULL;
#line 1441 "contacts-contact-sheet.c"
					}
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_g_object_unref0 (_email_list);
#line 1445 "contacts-contact-sheet.c"
				}
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_g_object_unref0 (emails);
#line 1449 "contacts-contact-sheet.c"
			}
#line 149 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp78_ = p;
#line 149 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp79_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp78_, FOLKS_TYPE_PHONE_DETAILS) ? ((FolksPhoneDetails*) _tmp78_) : NULL);
#line 149 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			phone_details = _tmp79_;
#line 150 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp80_ = phone_details;
#line 150 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			if (_tmp80_ != NULL) {
#line 1461 "contacts-contact-sheet.c"
				GeeArrayList* phones = NULL;
				FolksPhoneDetails* _tmp81_ = NULL;
				GeeSet* _tmp82_ = NULL;
				GeeSet* _tmp83_ = NULL;
				GeeArrayList* _tmp84_ = NULL;
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp81_ = phone_details;
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp82_ = folks_phone_details_get_phone_numbers (_tmp81_);
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp83_ = _tmp82_;
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp84_ = contacts_contact_sort_fields (FOLKS_TYPE_PHONE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, (GeeCollection*) _tmp83_);
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				phones = _tmp84_;
#line 1477 "contacts-contact-sheet.c"
				{
					GeeArrayList* _phone_list = NULL;
					GeeArrayList* _tmp85_ = NULL;
					GeeArrayList* _tmp86_ = NULL;
					gint _phone_size = 0;
					GeeArrayList* _tmp87_ = NULL;
					gint _tmp88_ = 0;
					gint _tmp89_ = 0;
					gint _phone_index = 0;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp85_ = phones;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp86_ = _g_object_ref0 (_tmp85_);
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_phone_list = _tmp86_;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp87_ = _phone_list;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp88_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp87_);
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp89_ = _tmp88_;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_phone_size = _tmp89_;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_phone_index = -1;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					while (TRUE) {
#line 1505 "contacts-contact-sheet.c"
						Block18Data* _data18_;
						gint _tmp90_ = 0;
						gint _tmp91_ = 0;
						gint _tmp92_ = 0;
						GeeArrayList* _tmp93_ = NULL;
						gint _tmp94_ = 0;
						gpointer _tmp95_ = NULL;
						ContactsApp* _tmp96_ = NULL;
						ContactsStore* _tmp97_ = NULL;
						gboolean _tmp98_ = FALSE;
						gboolean _tmp99_ = FALSE;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data18_ = g_slice_new0 (Block18Data);
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data18_->_ref_count_ = 1;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data18_->_data16_ = block16_data_ref (_data16_);
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp90_ = _phone_index;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_phone_index = _tmp90_ + 1;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp91_ = _phone_index;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp92_ = _phone_size;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						if (!(_tmp91_ < _tmp92_)) {
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							block18_data_unref (_data18_);
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_data18_ = NULL;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							break;
#line 1539 "contacts-contact-sheet.c"
						}
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp93_ = _phone_list;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp94_ = _phone_index;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp95_ = gee_abstract_list_get ((GeeAbstractList*) _tmp93_, _tmp94_);
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data18_->phone = (FolksPhoneFieldDetails*) _tmp95_;
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp96_ = contacts_app_app;
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp97_ = _tmp96_->contacts_store;
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp98_ = contacts_store_get_can_call (_tmp97_);
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp99_ = _tmp98_;
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						if (_tmp99_) {
#line 1559 "contacts-contact-sheet.c"
							GtkButton* button = NULL;
							ContactsTypeSet* _tmp100_ = NULL;
							ContactsTypeSet* _tmp101_ = NULL;
							FolksPhoneFieldDetails* _tmp102_ = NULL;
							gchar* _tmp103_ = NULL;
							gchar* _tmp104_ = NULL;
							FolksPhoneFieldDetails* _tmp105_ = NULL;
							gconstpointer _tmp106_ = NULL;
							const gchar* _tmp107_ = NULL;
							GtkButton* _tmp108_ = NULL;
							GtkButton* _tmp109_ = NULL;
							GtkButton* _tmp110_ = NULL;
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp100_ = contacts_typeset_get_phone ();
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp101_ = _tmp100_;
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp102_ = _data18_->phone;
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp103_ = contacts_typeset_format_type (_tmp101_, (FolksAbstractFieldDetails*) _tmp102_);
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp104_ = _tmp103_;
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp105_ = _data18_->phone;
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp106_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp105_);
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp107_ = _tmp106_;
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp108_ = contacts_contact_sheet_add_row_with_button (self, &i, _tmp104_, (const gchar*) _tmp107_);
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp109_ = _tmp108_;
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_g_free0 (_tmp104_);
#line 154 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							button = _tmp109_;
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp110_ = button;
#line 155 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							g_signal_connect_data (_tmp110_, "clicked", (GCallback) _________lambda32__gtk_button_clicked, block18_data_ref (_data18_), (GClosureNotify) block18_data_unref, 0);
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_g_object_unref0 (button);
#line 1602 "contacts-contact-sheet.c"
						} else {
							ContactsTypeSet* _tmp111_ = NULL;
							ContactsTypeSet* _tmp112_ = NULL;
							FolksPhoneFieldDetails* _tmp113_ = NULL;
							gchar* _tmp114_ = NULL;
							gchar* _tmp115_ = NULL;
							FolksPhoneFieldDetails* _tmp116_ = NULL;
							gconstpointer _tmp117_ = NULL;
							const gchar* _tmp118_ = NULL;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp111_ = contacts_typeset_get_phone ();
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp112_ = _tmp111_;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp113_ = _data18_->phone;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp114_ = contacts_typeset_format_type (_tmp112_, (FolksAbstractFieldDetails*) _tmp113_);
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp115_ = _tmp114_;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp116_ = _data18_->phone;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp117_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp116_);
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp118_ = _tmp117_;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							contacts_contact_sheet_add_row_with_label (self, &i, _tmp115_, (const gchar*) _tmp118_);
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_g_free0 (_tmp115_);
#line 1632 "contacts-contact-sheet.c"
						}
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						block18_data_unref (_data18_);
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data18_ = NULL;
#line 1638 "contacts-contact-sheet.c"
					}
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_g_object_unref0 (_phone_list);
#line 1642 "contacts-contact-sheet.c"
				}
#line 150 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_g_object_unref0 (phones);
#line 1646 "contacts-contact-sheet.c"
			}
#line 164 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp119_ = p;
#line 164 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp120_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp119_, FOLKS_TYPE_IM_DETAILS) ? ((FolksImDetails*) _tmp119_) : NULL);
#line 164 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			im_details = _tmp120_;
#line 165 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp121_ = im_details;
#line 165 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			if (_tmp121_ != NULL) {
#line 1658 "contacts-contact-sheet.c"
				{
					GeeIterator* _protocol_it = NULL;
					FolksImDetails* _tmp122_ = NULL;
					GeeMultiMap* _tmp123_ = NULL;
					GeeMultiMap* _tmp124_ = NULL;
					GeeSet* _tmp125_ = NULL;
					GeeSet* _tmp126_ = NULL;
					GeeIterator* _tmp127_ = NULL;
					GeeIterator* _tmp128_ = NULL;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp122_ = im_details;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp123_ = folks_im_details_get_im_addresses (_tmp122_);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp124_ = _tmp123_;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp125_ = gee_multi_map_get_keys (_tmp124_);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp126_ = _tmp125_;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp127_ = gee_iterable_iterator ((GeeIterable*) _tmp126_);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp128_ = _tmp127_;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_g_object_unref0 (_tmp126_);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_protocol_it = _tmp128_;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					while (TRUE) {
#line 1688 "contacts-contact-sheet.c"
						Block19Data* _data19_;
						GeeIterator* _tmp129_ = NULL;
						gboolean _tmp130_ = FALSE;
						GeeIterator* _tmp131_ = NULL;
						gpointer _tmp132_ = NULL;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data19_ = g_slice_new0 (Block19Data);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data19_->_ref_count_ = 1;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data19_->_data16_ = block16_data_ref (_data16_);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp129_ = _protocol_it;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp130_ = gee_iterator_next (_tmp129_);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						if (!_tmp130_) {
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							block19_data_unref (_data19_);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_data19_ = NULL;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							break;
#line 1712 "contacts-contact-sheet.c"
						}
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp131_ = _protocol_it;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp132_ = gee_iterator_get (_tmp131_);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data19_->protocol = (gchar*) _tmp132_;
#line 1720 "contacts-contact-sheet.c"
						{
							GeeIterator* _id_it = NULL;
							FolksImDetails* _tmp133_ = NULL;
							GeeMultiMap* _tmp134_ = NULL;
							GeeMultiMap* _tmp135_ = NULL;
							const gchar* _tmp136_ = NULL;
							GeeCollection* _tmp137_ = NULL;
							GeeCollection* _tmp138_ = NULL;
							GeeIterator* _tmp139_ = NULL;
							GeeIterator* _tmp140_ = NULL;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp133_ = im_details;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp134_ = folks_im_details_get_im_addresses (_tmp133_);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp135_ = _tmp134_;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp136_ = _data19_->protocol;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp137_ = gee_multi_map_get (_tmp135_, _tmp136_);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp138_ = _tmp137_;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp139_ = gee_iterable_iterator ((GeeIterable*) _tmp138_);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_tmp140_ = _tmp139_;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_g_object_unref0 (_tmp138_);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_id_it = _tmp140_;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							while (TRUE) {
#line 1753 "contacts-contact-sheet.c"
								Block20Data* _data20_;
								GeeIterator* _tmp141_ = NULL;
								gboolean _tmp142_ = FALSE;
								GeeIterator* _tmp143_ = NULL;
								gpointer _tmp144_ = NULL;
								FolksPersona* _tmp145_ = NULL;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								_data20_ = g_slice_new0 (Block20Data);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								_data20_->_ref_count_ = 1;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								_data20_->_data19_ = block19_data_ref (_data19_);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								_tmp141_ = _id_it;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								_tmp142_ = gee_iterator_next (_tmp141_);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								if (!_tmp142_) {
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									block20_data_unref (_data20_);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_data20_ = NULL;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									break;
#line 1778 "contacts-contact-sheet.c"
								}
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								_tmp143_ = _id_it;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								_tmp144_ = gee_iterator_get (_tmp143_);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								_data20_->id = (FolksImFieldDetails*) _tmp144_;
#line 168 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								_tmp145_ = p;
#line 168 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp145_, TPF_TYPE_PERSONA)) {
#line 1790 "contacts-contact-sheet.c"
									GtkButton* button = NULL;
									const gchar* _tmp146_ = NULL;
									gchar* _tmp147_ = NULL;
									gchar* _tmp148_ = NULL;
									FolksImFieldDetails* _tmp149_ = NULL;
									gconstpointer _tmp150_ = NULL;
									const gchar* _tmp151_ = NULL;
									GtkButton* _tmp152_ = NULL;
									GtkButton* _tmp153_ = NULL;
									GtkButton* _tmp154_ = NULL;
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp146_ = _data19_->protocol;
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp147_ = contacts_contact_format_im_service (_tmp146_, NULL);
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp148_ = _tmp147_;
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp149_ = _data20_->id;
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp150_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp149_);
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp151_ = _tmp150_;
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp152_ = contacts_contact_sheet_add_row_with_button (self, &i, _tmp148_, (const gchar*) _tmp151_);
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp153_ = _tmp152_;
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_g_free0 (_tmp148_);
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									button = _tmp153_;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp154_ = button;
#line 170 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									g_signal_connect_data (_tmp154_, "clicked", (GCallback) ___________lambda33__gtk_button_clicked, block20_data_ref (_data20_), (GClosureNotify) block20_data_unref, 0);
#line 168 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_g_object_unref0 (button);
#line 1827 "contacts-contact-sheet.c"
								}
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								block20_data_unref (_data20_);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								_data20_ = NULL;
#line 1833 "contacts-contact-sheet.c"
							}
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							_g_object_unref0 (_id_it);
#line 1837 "contacts-contact-sheet.c"
						}
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						block19_data_unref (_data19_);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_data19_ = NULL;
#line 1843 "contacts-contact-sheet.c"
					}
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_g_object_unref0 (_protocol_it);
#line 1847 "contacts-contact-sheet.c"
				}
			}
#line 187 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp155_ = p;
#line 187 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp156_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp155_, FOLKS_TYPE_URL_DETAILS) ? ((FolksUrlDetails*) _tmp155_) : NULL);
#line 187 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			url_details = _tmp156_;
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp157_ = url_details;
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			if (_tmp157_ != NULL) {
#line 1860 "contacts-contact-sheet.c"
				{
					GeeIterator* _url_it = NULL;
					FolksUrlDetails* _tmp158_ = NULL;
					GeeSet* _tmp159_ = NULL;
					GeeSet* _tmp160_ = NULL;
					GeeIterator* _tmp161_ = NULL;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp158_ = url_details;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp159_ = folks_url_details_get_urls (_tmp158_);
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp160_ = _tmp159_;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp161_ = gee_iterable_iterator ((GeeIterable*) _tmp160_);
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_url_it = _tmp161_;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					while (TRUE) {
#line 1879 "contacts-contact-sheet.c"
						GeeIterator* _tmp162_ = NULL;
						gboolean _tmp163_ = FALSE;
						FolksUrlFieldDetails* url = NULL;
						GeeIterator* _tmp164_ = NULL;
						gpointer _tmp165_ = NULL;
						const gchar* _tmp166_ = NULL;
						FolksUrlFieldDetails* _tmp167_ = NULL;
						gconstpointer _tmp168_ = NULL;
						const gchar* _tmp169_ = NULL;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp162_ = _url_it;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp163_ = gee_iterator_next (_tmp162_);
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						if (!_tmp163_) {
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							break;
#line 1897 "contacts-contact-sheet.c"
						}
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp164_ = _url_it;
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp165_ = gee_iterator_get (_tmp164_);
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						url = (FolksUrlFieldDetails*) _tmp165_;
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp166_ = _ ("Website");
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp167_ = url;
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp168_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp167_);
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp169_ = _tmp168_;
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						contacts_contact_sheet_add_row_with_link_button (self, &i, _tmp166_, (const gchar*) _tmp169_);
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_g_object_unref0 (url);
#line 1917 "contacts-contact-sheet.c"
					}
#line 189 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_g_object_unref0 (_url_it);
#line 1921 "contacts-contact-sheet.c"
				}
			}
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp170_ = p;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp171_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp170_, FOLKS_TYPE_NAME_DETAILS) ? ((FolksNameDetails*) _tmp170_) : NULL);
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			name_details = _tmp171_;
#line 194 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp172_ = name_details;
#line 194 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			if (_tmp172_ != NULL) {
#line 1934 "contacts-contact-sheet.c"
				FolksNameDetails* _tmp173_ = NULL;
				const gchar* _tmp174_ = NULL;
				const gchar* _tmp175_ = NULL;
				gboolean _tmp176_ = FALSE;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp173_ = name_details;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp174_ = folks_name_details_get_nickname (_tmp173_);
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp175_ = _tmp174_;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp176_ = contacts_is_set (_tmp175_);
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				if (_tmp176_) {
#line 1949 "contacts-contact-sheet.c"
					const gchar* _tmp177_ = NULL;
					FolksNameDetails* _tmp178_ = NULL;
					const gchar* _tmp179_ = NULL;
					const gchar* _tmp180_ = NULL;
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp177_ = _ ("Nickname");
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp178_ = name_details;
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp179_ = folks_name_details_get_nickname (_tmp178_);
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp180_ = _tmp179_;
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					contacts_contact_sheet_add_row_with_label (self, &i, _tmp177_, _tmp180_);
#line 1964 "contacts-contact-sheet.c"
				}
			}
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp181_ = p;
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp182_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp181_, FOLKS_TYPE_BIRTHDAY_DETAILS) ? ((FolksBirthdayDetails*) _tmp181_) : NULL);
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			birthday_details = _tmp182_;
#line 201 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp183_ = birthday_details;
#line 201 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			if (_tmp183_ != NULL) {
#line 1977 "contacts-contact-sheet.c"
				FolksBirthdayDetails* _tmp184_ = NULL;
				GDateTime* _tmp185_ = NULL;
				GDateTime* _tmp186_ = NULL;
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp184_ = birthday_details;
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp185_ = folks_birthday_details_get_birthday (_tmp184_);
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp186_ = _tmp185_;
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				if (_tmp186_ != NULL) {
#line 1989 "contacts-contact-sheet.c"
					const gchar* _tmp187_ = NULL;
					FolksBirthdayDetails* _tmp188_ = NULL;
					GDateTime* _tmp189_ = NULL;
					GDateTime* _tmp190_ = NULL;
					GDateTime* _tmp191_ = NULL;
					GDateTime* _tmp192_ = NULL;
					gchar* _tmp193_ = NULL;
					gchar* _tmp194_ = NULL;
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp187_ = _ ("Birthday");
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp188_ = birthday_details;
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp189_ = folks_birthday_details_get_birthday (_tmp188_);
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp190_ = _tmp189_;
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp191_ = g_date_time_to_local (_tmp190_);
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp192_ = _tmp191_;
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp193_ = g_date_time_format (_tmp192_, "%x");
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp194_ = _tmp193_;
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					contacts_contact_sheet_add_row_with_label (self, &i, _tmp187_, _tmp194_);
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_g_free0 (_tmp194_);
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_g_date_time_unref0 (_tmp192_);
#line 2020 "contacts-contact-sheet.c"
				}
			}
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp195_ = p;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp196_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp195_, FOLKS_TYPE_NOTE_DETAILS) ? ((FolksNoteDetails*) _tmp195_) : NULL);
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			note_details = _tmp196_;
#line 208 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp197_ = note_details;
#line 208 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			if (_tmp197_ != NULL) {
#line 2033 "contacts-contact-sheet.c"
				{
					GeeIterator* _note_it = NULL;
					FolksNoteDetails* _tmp198_ = NULL;
					GeeSet* _tmp199_ = NULL;
					GeeSet* _tmp200_ = NULL;
					GeeIterator* _tmp201_ = NULL;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp198_ = note_details;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp199_ = folks_note_details_get_notes (_tmp198_);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp200_ = _tmp199_;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp201_ = gee_iterable_iterator ((GeeIterable*) _tmp200_);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_note_it = _tmp201_;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					while (TRUE) {
#line 2052 "contacts-contact-sheet.c"
						GeeIterator* _tmp202_ = NULL;
						gboolean _tmp203_ = FALSE;
						FolksNoteFieldDetails* note = NULL;
						GeeIterator* _tmp204_ = NULL;
						gpointer _tmp205_ = NULL;
						const gchar* _tmp206_ = NULL;
						FolksNoteFieldDetails* _tmp207_ = NULL;
						gconstpointer _tmp208_ = NULL;
						const gchar* _tmp209_ = NULL;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp202_ = _note_it;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp203_ = gee_iterator_next (_tmp202_);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						if (!_tmp203_) {
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							break;
#line 2070 "contacts-contact-sheet.c"
						}
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp204_ = _note_it;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp205_ = gee_iterator_get (_tmp204_);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						note = (FolksNoteFieldDetails*) _tmp205_;
#line 210 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp206_ = _ ("Note");
#line 210 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp207_ = note;
#line 210 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp208_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp207_);
#line 210 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp209_ = _tmp208_;
#line 210 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						contacts_contact_sheet_add_row_with_label (self, &i, _tmp206_, (const gchar*) _tmp209_);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_g_object_unref0 (note);
#line 2090 "contacts-contact-sheet.c"
					}
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_g_object_unref0 (_note_it);
#line 2094 "contacts-contact-sheet.c"
				}
			}
#line 214 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp210_ = p;
#line 214 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp211_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp210_, FOLKS_TYPE_POSTAL_ADDRESS_DETAILS) ? ((FolksPostalAddressDetails*) _tmp210_) : NULL);
#line 214 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			addr_details = _tmp211_;
#line 215 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp212_ = addr_details;
#line 215 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			if (_tmp212_ != NULL) {
#line 2107 "contacts-contact-sheet.c"
				FolksPostalAddressDetails* _tmp240_ = NULL;
				GeeSet* _tmp241_ = NULL;
				GeeSet* _tmp242_ = NULL;
				gint _tmp243_ = 0;
				gint _tmp244_ = 0;
				{
					GeeIterator* _addr_it = NULL;
					FolksPostalAddressDetails* _tmp213_ = NULL;
					GeeSet* _tmp214_ = NULL;
					GeeSet* _tmp215_ = NULL;
					GeeIterator* _tmp216_ = NULL;
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp213_ = addr_details;
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp214_ = folks_postal_address_details_get_postal_addresses (_tmp213_);
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp215_ = _tmp214_;
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp216_ = gee_iterable_iterator ((GeeIterable*) _tmp215_);
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_addr_it = _tmp216_;
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					while (TRUE) {
#line 2131 "contacts-contact-sheet.c"
						GeeIterator* _tmp217_ = NULL;
						gboolean _tmp218_ = FALSE;
						FolksPostalAddressFieldDetails* addr = NULL;
						GeeIterator* _tmp219_ = NULL;
						gpointer _tmp220_ = NULL;
						gchar** strs = NULL;
						FolksPostalAddressFieldDetails* _tmp221_ = NULL;
						gconstpointer _tmp222_ = NULL;
						FolksPostalAddress* _tmp223_ = NULL;
						gint _tmp224_ = 0;
						gchar** _tmp225_ = NULL;
						gint strs_length1 = 0;
						gint _strs_size_ = 0;
						gchar* all_strs = NULL;
						gchar* _tmp226_ = NULL;
						gchar** _tmp227_ = NULL;
						gint _tmp227__length1 = 0;
						ContactsTypeSet* _tmp234_ = NULL;
						ContactsTypeSet* _tmp235_ = NULL;
						FolksPostalAddressFieldDetails* _tmp236_ = NULL;
						gchar* _tmp237_ = NULL;
						gchar* _tmp238_ = NULL;
						const gchar* _tmp239_ = NULL;
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp217_ = _addr_it;
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp218_ = gee_iterator_next (_tmp217_);
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						if (!_tmp218_) {
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							break;
#line 2163 "contacts-contact-sheet.c"
						}
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp219_ = _addr_it;
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp220_ = gee_iterator_get (_tmp219_);
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						addr = (FolksPostalAddressFieldDetails*) _tmp220_;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp221_ = addr;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp222_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp221_);
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp223_ = _tmp222_;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp225_ = contacts_contact_format_address ((FolksPostalAddress*) _tmp223_, &_tmp224_);
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						strs = _tmp225_;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						strs_length1 = _tmp224_;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_strs_size_ = strs_length1;
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp226_ = g_strdup ("");
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						all_strs = _tmp226_;
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp227_ = strs;
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp227__length1 = strs_length1;
#line 2193 "contacts-contact-sheet.c"
						{
							gchar** s_collection = NULL;
							gint s_collection_length1 = 0;
							gint _s_collection_size_ = 0;
							gint s_it = 0;
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							s_collection = _tmp227_;
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							s_collection_length1 = _tmp227__length1;
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
							for (s_it = 0; s_it < _tmp227__length1; s_it = s_it + 1) {
#line 2205 "contacts-contact-sheet.c"
								gchar* _tmp228_ = NULL;
								gchar* s = NULL;
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								_tmp228_ = g_strdup (s_collection[s_it]);
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
								s = _tmp228_;
#line 2212 "contacts-contact-sheet.c"
								{
									const gchar* _tmp229_ = NULL;
									const gchar* _tmp230_ = NULL;
									gchar* _tmp231_ = NULL;
									gchar* _tmp232_ = NULL;
									gchar* _tmp233_ = NULL;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp229_ = all_strs;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp230_ = s;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp231_ = g_strconcat (_tmp230_, "\n", NULL);
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp232_ = _tmp231_;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_tmp233_ = g_strconcat (_tmp229_, _tmp232_, NULL);
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_g_free0 (all_strs);
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									all_strs = _tmp233_;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_g_free0 (_tmp232_);
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
									_g_free0 (s);
#line 2237 "contacts-contact-sheet.c"
								}
							}
						}
#line 222 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp234_ = contacts_typeset_get_general ();
#line 222 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp235_ = _tmp234_;
#line 222 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp236_ = addr;
#line 222 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp237_ = contacts_typeset_format_type (_tmp235_, (FolksAbstractFieldDetails*) _tmp236_);
#line 222 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp238_ = _tmp237_;
#line 222 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_tmp239_ = all_strs;
#line 222 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						contacts_contact_sheet_add_row_with_label (self, &i, _tmp238_, _tmp239_);
#line 222 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_g_free0 (_tmp238_);
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_g_free0 (all_strs);
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						strs = (_vala_array_free (strs, strs_length1, (GDestroyNotify) g_free), NULL);
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
						_g_object_unref0 (addr);
#line 2263 "contacts-contact-sheet.c"
					}
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_g_object_unref0 (_addr_it);
#line 2267 "contacts-contact-sheet.c"
				}
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp240_ = addr_details;
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp241_ = folks_postal_address_details_get_postal_addresses (_tmp240_);
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp242_ = _tmp241_;
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp243_ = gee_collection_get_size ((GeeCollection*) _tmp242_);
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp244_ = _tmp243_;
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				if (_tmp244_ > 0) {
#line 2281 "contacts-contact-sheet.c"
					ContactsAddressMap* map = NULL;
					ContactsContact* _tmp245_ = NULL;
					FolksPostalAddressDetails* _tmp246_ = NULL;
					GeeSet* _tmp247_ = NULL;
					GeeSet* _tmp248_ = NULL;
					ContactsAddressMap* _tmp249_ = NULL;
					ContactsAddressMap* _tmp250_ = NULL;
					ContactsAddressMap* _tmp251_ = NULL;
					gint _tmp252_ = 0;
					gint _tmp253_ = 0;
#line 226 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp245_ = _data16_->c;
#line 226 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp246_ = addr_details;
#line 226 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp247_ = folks_postal_address_details_get_postal_addresses (_tmp246_);
#line 226 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp248_ = _tmp247_;
#line 226 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp249_ = contacts_address_map_new (_tmp245_, _tmp248_);
#line 226 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					g_object_ref_sink (_tmp249_);
#line 226 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					map = _tmp249_;
#line 227 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp250_ = map;
#line 227 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					contacts_address_map_load (_tmp250_);
#line 228 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp251_ = map;
#line 228 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp252_ = i;
#line 228 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp251_, 1, _tmp252_, 1, 1);
#line 229 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_tmp253_ = i;
#line 229 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					i = _tmp253_ + 1;
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
					_g_object_unref0 (map);
#line 2322 "contacts-contact-sheet.c"
				}
			}
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp254_ = i;
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			if (_tmp254_ != 3) {
#line 234 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				is_first_persona = FALSE;
#line 2331 "contacts-contact-sheet.c"
			}
#line 236 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp255_ = i;
#line 236 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_tmp256_ = last_store_position;
#line 236 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			if (_tmp255_ == _tmp256_) {
#line 2339 "contacts-contact-sheet.c"
				gint _tmp257_ = 0;
				GtkWidget* _tmp258_ = NULL;
#line 237 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp257_ = i;
#line 237 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp258_ = gtk_grid_get_child_at ((GtkGrid*) self, 0, _tmp257_ - 1);
#line 237 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				gtk_widget_destroy (_tmp258_);
#line 2348 "contacts-contact-sheet.c"
			}
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_g_object_unref0 (addr_details);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_g_object_unref0 (note_details);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_g_object_unref0 (birthday_details);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_g_object_unref0 (name_details);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_g_object_unref0 (url_details);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_g_object_unref0 (im_details);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_g_object_unref0 (phone_details);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_g_object_unref0 (details);
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			_g_object_unref0 (p);
#line 2368 "contacts-contact-sheet.c"
		}
#line 126 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_g_object_unref0 (_p_list);
#line 2372 "contacts-contact-sheet.c"
	}
#line 241 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_g_object_unref0 (personas);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_g_object_unref0 (name_label);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_g_object_unref0 (image_frame);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	block16_data_unref (_data16_);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_data16_ = NULL;
#line 2386 "contacts-contact-sheet.c"
}


void contacts_contact_sheet_clear (ContactsContactSheet* self) {
	GList* _tmp0_ = NULL;
#line 244 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	g_return_if_fail (self != NULL);
#line 245 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	_tmp0_ = gtk_container_get_children ((GtkContainer*) self);
#line 2396 "contacts-contact-sheet.c"
	{
		GList* w_collection = NULL;
		GList* w_it = NULL;
#line 245 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		w_collection = _tmp0_;
#line 245 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		for (w_it = w_collection; w_it != NULL; w_it = w_it->next) {
#line 2404 "contacts-contact-sheet.c"
			GtkWidget* w = NULL;
#line 245 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
			w = (GtkWidget*) w_it->data;
#line 2408 "contacts-contact-sheet.c"
			{
				GtkWidget* _tmp1_ = NULL;
#line 246 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				_tmp1_ = w;
#line 246 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
				gtk_widget_destroy (_tmp1_);
#line 2415 "contacts-contact-sheet.c"
			}
		}
#line 245 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
		_g_list_free0 (w_collection);
#line 2420 "contacts-contact-sheet.c"
	}
}


static void contacts_contact_sheet_class_init (ContactsContactSheetClass * klass) {
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-sheet.vala"
	contacts_contact_sheet_parent_class = g_type_class_peek_parent (klass);
#line 2428 "contacts-contact-sheet.c"
}


static void contacts_contact_sheet_instance_init (ContactsContactSheet * self) {
}


GType contacts_contact_sheet_get_type (void) {
	static volatile gsize contacts_contact_sheet_type_id__volatile = 0;
	if (g_once_init_enter (&contacts_contact_sheet_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ContactsContactSheetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) contacts_contact_sheet_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ContactsContactSheet), 0, (GInstanceInitFunc) contacts_contact_sheet_instance_init, NULL };
		GType contacts_contact_sheet_type_id;
		contacts_contact_sheet_type_id = g_type_register_static (gtk_grid_get_type (), "ContactsContactSheet", &g_define_type_info, 0);
		g_once_init_leave (&contacts_contact_sheet_type_id__volatile, contacts_contact_sheet_type_id);
	}
	return contacts_contact_sheet_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



